<?php
namespace Teknisa\PLA\Modules\Cardapio\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use DateTime;
use DateInterval;

class Pla05900AssistenteCardapio extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $crudService;
    protected $parameterBag;
    protected $dataSourceManager;
    protected $environment;
    protected $entityManager;
    protected $util;
    protected $newCode;
    protected $assistenteCardapioService;
    protected $paramGeral;
    protected $paramFiliais;

    public function __construct($crudService, $parameterBag, $dataSourceManager, $environment, $entityManager, $util, $newCode, $assistenteCardapioService) {
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->dataSourceManager = $dataSourceManager;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->util = $util;
        $this->newCode = $newCode;
        $this->assistenteCardapioService = $assistenteCardapioService;
    }
    
    public function validateAndExportPeriod(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $nrlogintcard = [];
        $this->paramFiliais = $this->assistenteCardapioService->getParamFilial($row['UNIDADES']);
        $this->paramGeral = $this->assistenteCardapioService->getParamGeral();
        $invalidFiliais = array();
        $dtDestIni = strtotime($this->formatDateYMD($row['DTDESTINI']));
        foreach($this->paramFiliais as $param) {
            if(strtotime($this->formatDateYMD($param['DTPROCESSA'], $this->paramGeral['QTDIABLOQCAR'])) > $dtDestIni) {
                $invalidFiliais[] = $param['CDFILIAL'];
            }
        }
        if(sizeof($invalidFiliais)) {
            // $response->setError(new \Zeedhi\Framework\DTO\Response\Error("A(s) unidade(s) a seguir possui(em) cardápio bloqueado: ".implode("<br>", $invalidFiliais), 1));
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error("Data inicial de destino não pode ser menor que a data de processamento da unidade selecionada.", 1));
        } else {
            $nrlistaPeriodo = $this->util->insertLista($row['DATES']);
            $nrlogintcard = $this->validateServicos($row, $nrlistaPeriodo, $response);
        }
         
         $response->addDataSet(new DataSet('nrlogintcard', $nrlogintcard));
    }
    
    private function validateServicos($row, $nrlistaPeriodo, $response) {
        $servicosBloq = array();
        $servicos = array();
        $nrlistaToDelete = array();
        foreach ($row['SERVICOS'] as $servico) {
            $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
            $nrlistaToDelete[] = $nrlista;
            $servico['DTMESCARDAPIO'] = $row['DTMESCARDAPIO'];
            $servico['DTMESCARDAPIOINI'] = $row['DTMESCARDAPIOINI'];
            $row['MODOPROC'] = $this->assistenteCardapioService->getTipoOperador();
            if($this->paramGeral['IDUTCARDPADR'] === 'D' && $row['MODOPROC'] === 'M' && $servico['IDCARDDESCENTR'] === 'S') {
                if(sizeof($this->assistenteCardapioService->checkCtrlAprovCard($servico)) === 0) {
                    $this->assistenteCardapioService->insertCnfcamesLista($row, $servico, $nrlista);
                    $servicos[] = $servico['CDFILIORIG'].'|'.$servico['CDSERVORIG'].'|'.$nrlista.'_'.$servico['CDFILIDEST'].'|'.$servico['CDSERVDEST'];
                } else {
                    $servicosBloq[] = $servico['CDFILIDEST'].'|'.$servico['CDSERVDEST'].' '.$servico['NMSERVDEST'] ;
                }
            } else {
                $this->assistenteCardapioService->insertCnfcamesLista($row, $servico, $nrlista);
                $servicos[] = $servico['CDFILIORIG'].'|'.$servico['CDSERVORIG'].'|'.$nrlista.'_'.$servico['CDFILIDEST'].'|'.$servico['CDSERVDEST'];
            }
        }
        if(!empty($servicosBloq)){
            $response->addDataSet(new DataSet('ServicosBloq',$servicosBloq));
        }
        $nrlistaServicos = $this->util->insertLista($servicos);
        $nrlogintcard = $this->assistenteCardapioService->exportaCardapioCompleta($row, $nrlistaPeriodo, $nrlistaServicos);
        foreach ($nrlistaToDelete as $lista) {
            $this->util->deleteLista($lista);
        }
        $this->util->deleteLista($nrlistaServicos);
        $this->util->deleteLista($nrlistaPeriodo);
        return $nrlogintcard;
    }
    
    private function formatDateYMD($date = null, $interval = null) {
        $d = new DateTime();
        if($date) {
            $daux = explode(" ", $date)[0];
            $daux = explode("/", $daux);
            try{
                $d->setDate($daux[2], $daux[1], $daux[0]);
            } catch (Exception $e) {
            }
    
        }
        if($interval && $interval > 0){
            $d->add( new DateInterval('P'.$interval.'D'));
        }
        return $d->format('Ymd');
    }
    
    public function verificaNrlogintcard(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $nrlogintcard = $row[0];
        $nrorg = $row[1];
        
        $conditions = array(
 		    array(
			    "columnName" => "NRLOGINTCARD",
			    "operator" => "=",
			    "value" => $nrlogintcard
			    ),
			array(
			    "columnName" => "NRORG",
			    "operator" => "=",
			    "value" => $nrorg
			    )    
	    );
	    
	    $dataSet = $this->crudService->getFilteredDataSet("logintcard", $conditions);
	    $logs = $dataSet->getRows();
        $response->addDataSet(new DataSet('logs', $logs));
    }
    
    public function permissaoOperador($request, $response) {
        $grupoper = $this->crudService->getFilteredDataSet("grupoper", array());
        if(!empty($grupoper->getRows())){
            $conditions = array(
                array(
    			    "columnName" => "CDOPERADOR",
    			    "operator" => "=",
    			    "value" => $this->environment->getCdOperador()
    		    )
    	    );
    	    $dataSet = $this->crudService->getFilteredDataSet("pla05900_permicao_operador", $conditions);
    	    $response->addDataSet(new DataSet('pla05900_permicao_operador', array(!empty($dataSet->getRows()))));
        } else{
            $response->addDataSet(new DataSet('pla05900_permicao_operador', array(true)));
        }
    }
}