<?php
namespace Teknisa\PLA\Modules\Parametros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\GER\Services\CrudService;
use Doctrine\DBAL\Connection;
use Exception;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Pla06400MetaParaRestoIngestaSobraLimpaService extends \Teknisa\GER\Controllers\TeknisaCrud {

	protected $connection;
	protected $crudservice;
	protected $parameterbag;
	protected $dataSourceName = "metarisl";
	
    public function __construct($crudservice, $parameterbag, $entityManager) {
        $this->crudservice = $crudservice;
        $this->parameterbag = $parameterbag;
        $this->connection = $entityManager->getConnection();
    }

    function isEmptyOrBlank($value){
        return !isset($value) || $this->isBlank($value);
    }
    
    function isBlank($value){
        $newStr = str_replace(" ", "", $value);
        return strlen($newStr) === 0;
    }

    function valueToFloat($value){
        if(is_string($value) && !$this->isEmptyOrBlank($value)){
            $dotPos   = strpos($value, ".");
            $commaPos = strpos($value, ",");
            if($commaPos == false && $dotPos == false){
                return floatval($value);
            } 
            $dotPos   = $dotPos   !== false ? $dotPos   : -1;
            $commaPos = $commaPos !== false ? $commaPos : -1;
            if($commaPos > $dotPos){
                $firstReplace = str_replace(".", "", $value);
                $secondReplace = str_replace(",", ".", $firstReplace);
                return floatval($secondReplace);
            } 
            if($commaPos < $dotPos){
                $firstReplace = str_replace(",", "", $value);
                return floatval($firstReplace);
            }
        } else {
            return $value;
        }
    }
    
    public function saveRestoIngestaTabChanges($data){
        try{
            $sql = "UPDATE PARAMPLANEJA SET VRPESOPORCREIN = :VRPESOPORCREIN, 
                VRMETAPESOREIN = :VRMETAPESOREIN WHERE CDFILIAL = :CDFILIAL";
            
            $data['VRPESOPORCREIN'] = $this->valueToFloat($data['VRPESOPORCREIN']);
            $data['VRMETAPESOREIN'] = $this->valueToFloat($data['VRMETAPESOREIN']);
            $params = array(
                "VRPESOPORCREIN" => (float) $data['VRPESOPORCREIN'],    
                "VRMETAPESOREIN" => (float) $data['VRMETAPESOREIN'],    
                "CDFILIAL" => $data['CDFILIAL']    
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
            
        } catch (\Exception $e){
            throw $e;
        }
    }
    
    public function saveSobraLimpaTabChanges($data){
        try{
            $sql = "UPDATE PARAMPLANEJA SET VRPESOPORCSOLI = :VRPESOPORCSOLI, 
                VRMETAPESOSOLI = :VRMETAPESOSOLI WHERE CDFILIAL = :CDFILIAL";
            
            $data['VRPESOPORCSOLI'] = $this->valueToFloat($data['VRPESOPORCSOLI']);
            $data['VRMETAPESOSOLI'] = $this->valueToFloat($data['VRMETAPESOSOLI']);
            $params = array(
                "VRPESOPORCSOLI" => (float) $data['VRPESOPORCSOLI'],    
                "VRMETAPESOSOLI" => (float) $data['VRMETAPESOSOLI'],    
                "CDFILIAL" => $data['CDFILIAL']    
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
            
        } catch (\Exception $e){
            throw $e;
        }
    }
    
    public function includeGrupoTipoPrato($data, $cdfilial){
        try{
            $sql = "SELECT * FROM GRTIPOPRRISL 
                            WHERE CDFILIAL =:CDFILIAL 
                                AND IDCUSTOREINSOLI = :IDCUSTOREINSOLI 
                                AND CDGRTIPOPR = :CDGRTIPOPR";
            
            $params = array(
                "CDFILIAL" => $cdfilial,
                "IDCUSTOREINSOLI" => $data['IDCUSTOREINSOLI'],
                "CDGRTIPOPR" => $data['CDGRTIPOPR']
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
            $resultado = $query->fetch();
            
            if(!$resultado){
            
                $sql = "INSERT INTO GRTIPOPRRISL 
                            (CDFILIAL, IDCUSTOREINSOLI, CDGRTIPOPR) 
                        VALUES
                            (:CDFILIAL, :IDCUSTOREINSOLI, :CDGRTIPOPR)";
                
                
                $params = array(
                    "CDFILIAL" => $cdfilial,
                    "IDCUSTOREINSOLI" => $data['IDCUSTOREINSOLI'],
                    "CDGRTIPOPR" => $data['CDGRTIPOPR']
                );
                
                $query = $this->connection->prepare($sql);
                $query->execute($params);
            }
            
        }catch(\Exception $e){
            throw $e;
        }
    }
    
    public function deleteGrupoTipoPrato($data, $cdfilial){
        try{
            $sql = "DELETE FROM GRTIPOPRRISL
                    WHERE
                    CDFILIAL = :CDFILIAL AND
                    IDCUSTOREINSOLI = :IDCUSTOREINSOLI AND
                    CDGRTIPOPR = :CDGRTIPOPR";
                
            $params = array(
                "CDFILIAL" => $cdfilial,
                "IDCUSTOREINSOLI" => $data['IDCUSTOREINSOLI'],
                "CDGRTIPOPR" => $data['CDGRTIPOPR']
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
            
        }catch(\Exception $e){
            throw $e;
        }
    }
    
    public function deleteDate($row){
        try{
            $sql = "DELETE FROM METARISL
                    WHERE
                      CDFILIAL = :CDFILIAL AND
                      DTREFMETRISL = :DTREFMETRISL";
                
            $params = array(
                "CDFILIAL" => $row['CDFILIAL'],
                "DTREFMETRISL" => $row['DTREFMETRISL']
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
            
        }catch(\Exception $e){
            throw $e;
        }
    }
    
}
    